@@ -17,7 +17,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * 2006-2008 © Øyvind Kolås.
  */
@@ -130,6 +130,11 @@ type_name##_register_type (GTypeModule *type_module)                    \
 #define MKCLASS(a)  MKCLASS2(a)
 #define MKCLASS2(a) a##Class
 
+#ifdef GEGL_OP_BASE
+#define GEGL_OP_Parent GeglOperation
+#define GEGL_OP_PARENT GEGL_TYPE_OPERATION
+#endif
+
 #ifdef GEGL_OP_POINT_FILTER
 #define GEGL_OP_Parent GeglOperationPointFilter
 #define GEGL_OP_PARENT GEGL_TYPE_OPERATION_POINT_FILTER
@@ -277,7 +282,7 @@ gegl_module_register (GTypeModule *module)
 #define property_pointer(name, label, def_val)    ITEM(name,label,def_val,pointer)
 #define property_object(name, label, def_val)     ITEM2(name,label,def_val,object)
 #define property_enum(name, label, enm, enum_name, def_val)  ITEM(name,label,def_val,pointer)
-#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,int)
+#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,uint)
 #define property_format(name, label, def_val)     ITEM(name,label,def_val,pointer)
 #define property_curve(name, label, def_val)      ITEM2(name,label,def_val,object)
 #define property_path(name, label, def_val)       ITEM2(name,label,def_val,object)
@@ -286,12 +291,14 @@ gegl_module_register (GTypeModule *module)
 
 #define enum_start(enum_name)   typedef enum {
 #define enum_value(value, nick, name)    value ,
+#define enum_value_skip(value)           value ,
 #define enum_end(enum)          } enum ;
 
 #include GEGL_OP_C_FILE
 
 #undef enum_start
 #undef enum_value
+#undef enum_value_skip
 #undef enum_end
 
 #ifdef GETTEXT_PACKAGE
@@ -311,12 +318,14 @@ static GType enum_name ## _get_type (void)               \
 #define enum_value(value, nick, name)                \
       { value, name, nick },
 
+#define enum_value_skip(value)
+
 #define enum_end(enum)                                            \
       { 0, NULL, NULL }                                           \
     };                                                            \
     if (gegl_op_gettext_package)                                  \
       {                                                           \
-        gint i;                                                   \
+        guint i;                                                   \
         for (i = 0; i < G_N_ELEMENTS (values); i++)               \
           if (values[i].value_name)                               \
             values[i].value_name =                                \
@@ -346,9 +355,11 @@ static GType enum_name ## _get_type (void)               \
 #undef property_path
 #undef enum_start
 #undef enum_value
+#undef enum_value_skip
 #undef enum_end
 #define enum_start(enum_name)
 #define enum_value(value, nick, name)
+#define enum_value_skip(value)
 #define enum_end(enum)
 
 /* Properties */
@@ -370,7 +381,7 @@ struct _GeglProperties
 #define property_pointer(name, label, def_val)         gpointer    name;
 #define property_format(name, label, def_val)          gpointer    name;
 #define property_enum(name, label, enum, enum_name, def_val) enum        name;
-#define property_seed(name, label, rand_name)          gint        name;\
+#define property_seed(name, label, rand_name)          guint       name;\
                                                        GeglRandom *rand_name;
 
 #include GEGL_OP_C_FILE
@@ -416,7 +427,7 @@ enum
 #define property_pointer(name, label, def_val)    ITEM(name,label,def_val,pointer)
 #define property_format(name, label, def_val)     ITEM(name,label,def_val,pointer)
 #define property_enum(name, label, enm, enum_name, def_val) ITEM(name,label,def_val,enum)
-#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,int)
+#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,uint)
 
 #include GEGL_OP_C_FILE
 
@@ -489,8 +500,7 @@ set_property (GObject      *gobject,
       break;
 #define property_string(name, label, def_val)                         \
     case PROP_##name:                                                 \
-      if (properties->name)                                           \
-        g_free (properties->name);                                    \
+      g_free (properties->name);                                      \
       properties->name = g_value_dup_string (value);                  \
       break;
 #define property_boolean(name, label, def_val)                        \
@@ -499,39 +509,34 @@ set_property (GObject      *gobject,
       break;
 #define property_file_path(name, label, def_val)                      \
     case PROP_##name:                                                 \
-      if (properties->name)                                           \
-        g_free (properties->name);                                    \
+      g_free (properties->name);                                      \
       properties->name = g_value_dup_string (value);                  \
       break;
 #define property_uri(name, label, def_val)                            \
     case PROP_##name:                                                 \
-      if (properties->name)                                           \
-        g_free (properties->name);                                    \
+      g_free (properties->name);                                      \
       properties->name = g_value_dup_string (value);                  \
       break;
 #define property_object(name, label, def_val)                         \
     case PROP_##name:                                                 \
-      if (properties->name != NULL)                                   \
-         g_object_unref (properties->name);                           \
-      properties->name = g_value_dup_object (value);                  \
+      g_clear_object (&properties->name);                             \
+      properties->name = G_OBJECT (g_value_dup_object (value));       \
       break;
 #define property_curve(name, label, def_val)                          \
     case PROP_##name:                                                 \
-      if (properties->name != NULL)                                   \
-         g_object_unref (properties->name);                           \
-      properties->name = g_value_dup_object (value);                  \
+      g_clear_object (&properties->name);                             \
+      properties->name = GEGL_CURVE (g_value_dup_object (value));     \
       break;
 #define property_color(name, label, def_val)                          \
     case PROP_##name:                                                 \
-      if (properties->name != NULL)                                   \
-         g_object_unref (properties->name);                           \
-      properties->name = g_value_dup_object (value);                  \
+      g_clear_object (&properties->name);                             \
+      properties->name = GEGL_COLOR (g_value_dup_object (value));     \
       break;
 #define property_audio_fragment(name, label, def_val)                 \
     case PROP_##name:                                                 \
-      if (properties->name != NULL)                                   \
-         g_object_unref (properties->name);                           \
-      properties->name = g_value_dup_object (value);                  \
+      g_clear_object (&properties->name);                             \
+      properties->name =                                              \
+        GEGL_AUDIO_FRAGMENT (g_value_dup_object (value));              \
       break;
 #define property_path(name, label, def_val)                           \
     case PROP_##name:                                                 \
@@ -543,7 +548,7 @@ set_property (GObject      *gobject,
           properties->path_changed_handler = 0;                       \
           g_object_unref (properties->name);                          \
         }                                                             \
-      properties->name = g_value_dup_object (value);                  \
+      properties->name = GEGL_PATH (g_value_dup_object (value));      \
       if (properties->name != NULL)                                   \
         {                                                             \
           properties->path_changed_handler =                          \
@@ -561,11 +566,11 @@ set_property (GObject      *gobject,
       break;
 #define property_enum(name, label, enum, enum_name, def_val)          \
     case PROP_##name:                                                 \
-      properties->name = g_value_get_enum (value);                    \
+      properties->name = (enum) g_value_get_enum (value);             \
       break;
 #define property_seed(name, label, rand_name)                         \
     case PROP_##name:                                                 \
-      properties->name = g_value_get_int (value);                     \
+      properties->name = g_value_get_uint (value);                     \
       if (!properties->rand_name)                                     \
         properties->rand_name = gegl_random_new_with_seed (properties->name);\
       else                                                            \
@@ -605,54 +610,22 @@ static void gegl_op_destroy_notify (gpointer data)
 #define property_double(name, label, def_val)
 #define property_int(name, label, def_val) 
 #define property_string(name, label, ...)      \
-  if (properties->name)                             \
-    {                                               \
-      g_free (properties->name);                    \
-      properties->name = NULL;                      \
-    }
+  g_clear_pointer (&properties->name, g_free);
 #define property_boolean(name, label, def_val)
 #define property_file_path(name, label, def_val)    \
-  if (properties->name)                             \
-    {                                               \
-      g_free (properties->name);                    \
-      properties->name = NULL;                      \
-    }
+  g_clear_pointer (&properties->name, g_free);
 #define property_uri(name, label, def_val)          \
-  if (properties->name)                             \
-    {                                               \
-      g_free (properties->name);                    \
-      properties->name = NULL;                      \
-    }
+  g_clear_pointer (&properties->name, g_free);
 #define property_object(name, label, def_val)       \
-  if (properties->name)                             \
-    {                                               \
-      g_object_unref (properties->name);            \
-      properties->name = NULL;                      \
-    }
+  g_clear_object (&properties->name);
 #define property_curve(name, label, def_val)       \
-  if (properties->name)                             \
-    {                                               \
-      g_object_unref (properties->name);            \
-      properties->name = NULL;                      \
-    }
+  g_clear_object (&properties->name);
 #define property_color(name, label, def_val)       \
-  if (properties->name)                             \
-    {                                               \
-      g_object_unref (properties->name);            \
-      properties->name = NULL;                      \
-    }
+  g_clear_object (&properties->name);
 #define property_audio_fragment(name, label, def_val) \
-  if (properties->name)                             \
-    {                                               \
-      g_object_unref (properties->name);            \
-      properties->name = NULL;                      \
-    }
+  g_clear_object (&properties->name);
 #define property_path(name, label, def_val)         \
-  if (properties->name)                             \
-    {                                               \
-      g_object_unref (properties->name);            \
-      properties->name = NULL;                      \
-    }
+  g_clear_object (&properties->name);
 #define property_pointer(name, label, ...)
 #define property_format(name, label, ...)
 #define property_enum(name, label, ...)
